@@ -287,6 +287,79 @@ var FlagRegistry = []Flag{
 		FlagAddMethod: "BoolVar",
 		DefinedOn:     []string{"dev", "run", "debug", "deploy", "render", "build", "delete", "diagnose"},
 	},
+	{
+		Name:          "trigger",
+		Usage:         "How is change detection triggered? (polling, notify, or manual)",
+		Value:         &opts.Trigger,
+		DefValue:      "notify",
+		FlagAddMethod: "StringVar",
+		DefinedOn:     []string{"dev", "debug"},
+	},
+	{
+		Name:     "auto-build",
+		Usage:    "When set to false, builds wait for API request instead of running automatically",
+		Hidden:   true,
+		Value:    &opts.AutoBuild,
+		DefValue: true,
+		DefValuePerCommand: map[string]interface{}{
+			"dev":   true,
+			"debug": false,
+		},
+		FlagAddMethod: "BoolVar",
+		DefinedOn:     []string{"dev", "debug"},
+	},
+	{
+		Name:     "auto-sync",
+		Usage:    "When set to false, syncs wait for API request instead of running automatically",
+		Hidden:   true,
+		Value:    &opts.AutoSync,
+		DefValue: true,
+		DefValuePerCommand: map[string]interface{}{
+			"dev":   true,
+			"debug": false,
+		},
+		FlagAddMethod: "BoolVar",
+		DefinedOn:     []string{"dev", "debug"},
+	},
+	{
+		Name:     "auto-deploy",
+		Usage:    "When set to false, deploys wait for API request instead of running automatically",
+		Hidden:   true,
+		Value:    &opts.AutoDeploy,
+		DefValue: true,
+		DefValuePerCommand: map[string]interface{}{
+			"dev":   true,
+			"debug": false,
+		},
+		FlagAddMethod: "BoolVar",
+		DefinedOn:     []string{"dev", "debug"},
+	},
+	{
+		Name:          "watch-image",
+		Shorthand:     "w",
+		Usage:         "Choose which artifacts to watch. Artifacts with image names that contain the expression will be watched only. Default is to watch sources for all artifacts",
+		Value:         &opts.TargetImages,
+		DefValue:      []string{},
+		FlagAddMethod: "StringSliceVar",
+		DefinedOn:     []string{"dev", "debug"},
+	},
+	{
+		Name:          "watch-poll-interval",
+		Shorthand:     "i",
+		Usage:         "Interval (in ms) between two checks for file changes",
+		Value:         &opts.WatchPollInterval,
+		DefValue:      1000,
+		FlagAddMethod: "IntVar",
+		DefinedOn:     []string{"dev", "debug"},
+	},
+	{
+		Name:          "add-skaffold-labels",
+		Usage:         "Add Skaffold-specific labels to rendered manifest. If false, custom labels are still applied. Helpful for GitOps model where Skaffold is not the deployer.",
+		Value:         &opts.AddSkaffoldLabels,
+		DefValue:      true,
+		FlagAddMethod: "BoolVar",
+		DefinedOn:     []string{"render"},
+	},
 }
 
 func (fl *Flag) flag() *pflag.Flag {
