@@ -18,6 +18,7 @@ package integration
 
 import (
 	"io/ioutil"
+	"os"
 	"path/filepath"
 	"testing"
 
@@ -26,9 +27,7 @@ import (
 )
 
 func TestInitCompose(t *testing.T) {
-	if testing.Short() || RunOnGCP() {
-		t.Skip("skipping kind integration test")
-	}
+	MarkIntegrationTest(t, CanRunWithoutGcp)
 
 	tests := []struct {
 		name string
@@ -57,9 +56,7 @@ func TestInitCompose(t *testing.T) {
 }
 
 func TestInitManifestGeneration(t *testing.T) {
-	if testing.Short() || RunOnGCP() {
-		t.Skip("skipping kind integration test")
-	}
+	MarkIntegrationTest(t, CanRunWithoutGcp)
 
 	tests := []struct {
 		name                  string
@@ -97,6 +94,30 @@ func TestInitManifestGeneration(t *testing.T) {
 	}
 }
 
+func TestInitKustomize(t *testing.T) {
+	MarkIntegrationTest(t, CanRunWithoutGcp)
+
+	testutil.Run(t, "kustomize init", func(t *testutil.T) {
+		dir := "examples/getting-started-kustomize"
+		ns, _ := SetupNamespace(t.T)
+
+		initArgs := []string{"--force"}
+		defer func() {
+			path := filepath.Join(dir, "skaffold.yaml.out")
+			_, err := os.Stat(path)
+			if os.IsNotExist(err) {
+				return
+			}
+			os.Remove(path)
+		}()
+		skaffold.Init(initArgs...).InDir(dir).WithConfig("skaffold.yaml.out").RunOrFail(t.T)
+
+		checkGeneratedConfig(t, dir)
+
+		skaffold.Run().InDir(dir).WithConfig("skaffold.yaml.out").InNs(ns.Name).RunOrFail(t.T)
+	})
+}
+
 func checkGeneratedConfig(t *testutil.T, dir string) {
 	expectedOutput, err := ioutil.ReadFile(filepath.Join(dir, "skaffold.yaml"))
 	t.CheckNoError(err)
