@@ -94,14 +94,29 @@ func TestRun(t *testing.T) {
 			pods:        []string{"getting-started"},
 		},
 		{
-			description: "buildpacks",
+			description: "buildpacks Go",
 			dir:         "examples/buildpacks",
 			deployments: []string{"web"},
 		},
+		{
+			description: "buildpacks NodeJS",
+			dir:         "examples/buildpacks-node",
+			deployments: []string{"web"},
+		},
+		{
+			description: "buildpacks Python",
+			dir:         "examples/buildpacks-python",
+			deployments: []string{"web"},
+		},
+		{
+			description: "buildpacks Java",
+			dir:         "examples/buildpacks-java",
+			deployments: []string{"web"},
+		},
 		{
 			description: "kustomize",
 			dir:         "examples/getting-started-kustomize",
-			deployments: []string{"skaffold-kustomize"},
+			deployments: []string{"skaffold-kustomize-dev"},
 		},
 	}
 	for _, test := range tests {
