@@ -53,6 +53,9 @@ const (
 
 	DefaultBusyboxImage = "busybox"
 
+	// DefaultDebugHelpersRegistry is the default location used for the helper images for `debug`.
+	DefaultDebugHelpersRegistry = "gcr.io/gcp-dev-tools/duct-tape"
+
 	UpdateCheckEnvironmentVariable = "SKAFFOLD_UPDATE_CHECK"
 
 	DefaultSkaffoldDir = ".skaffold"
