@@ -73,11 +73,6 @@ func (c *CLI) Apply(ctx context.Context, out io.Writer, manifests ManifestList)
 	return nil
 }
 
-// Kustomize runs `kubectl kustomize` with the provided args
-func (c *CLI) Kustomize(ctx context.Context, args []string) ([]byte, error) {
-	return c.RunOut(ctx, "kustomize", c.args(nil, args...)...)
-}
-
 // ReadManifests reads a list of manifests in yaml format.
 func (c *CLI) ReadManifests(ctx context.Context, manifests []string) (ManifestList, error) {
 	var list []string
