@@ -212,10 +212,10 @@ func getMinikubeDockerEnv(minikubeProfile string) (map[string]string, error) {
 
 	env := map[string]string{}
 	for _, line := range strings.Split(string(out), "\n") {
-		if line == "" {
+		if line == "" || strings.HasPrefix(line, "#") {
 			continue
 		}
-		kv := strings.Split(line, "=")
+		kv := strings.SplitN(line, "=", 2)
 		if len(kv) != 2 {
 			return nil, fmt.Errorf("unable to parse minikube docker-env keyvalue: %s, line: %s, output: %s", kv, line, string(out))
 		}
