@@ -27,7 +27,6 @@ import (
 
 	"github.com/sirupsen/logrus"
 	v1 "k8s.io/api/core/v1"
-	"k8s.io/apimachinery/pkg/watch"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/color"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubectl"
@@ -37,13 +36,12 @@ import (
 type LogAggregator struct {
 	output      io.Writer
 	kubectlcli  *kubectl.CLI
-	podSelector PodSelector
-	namespaces  []string
+	podWatcher  PodWatcher
 	colorPicker ColorPicker
 
 	muted             int32
 	sinceTime         time.Time
-	cancel            context.CancelFunc
+	events            chan PodEvent
 	trackedContainers trackedContainers
 	outputLock        sync.Mutex
 }
@@ -53,12 +51,9 @@ func NewLogAggregator(out io.Writer, cli *kubectl.CLI, imageNames []string, podS
 	return &LogAggregator{
 		output:      out,
 		kubectlcli:  cli,
-		podSelector: podSelector,
-		namespaces:  namespaces,
+		podWatcher:  NewPodWatcher(podSelector, namespaces),
 		colorPicker: NewColorPicker(imageNames),
-		trackedContainers: trackedContainers{
-			ids: map[string]bool{},
-		},
+		events:      make(chan PodEvent),
 	}
 }
 
@@ -79,38 +74,26 @@ func (a *LogAggregator) Start(ctx context.Context) error {
 		return nil
 	}
 
-	cancelCtx, cancel := context.WithCancel(ctx)
-	a.cancel = cancel
-
-	aggregate := make(chan watch.Event)
-	stopWatchers, err := AggregatePodWatcher(a.namespaces, aggregate)
+	a.podWatcher.Register(a.events)
+	stopWatcher, err := a.podWatcher.Start()
 	if err != nil {
-		stopWatchers()
-		return fmt.Errorf("initializing aggregate pod watcher: %w", err)
+		return err
 	}
 
 	go func() {
-		defer stopWatchers()
+		defer stopWatcher()
 
 		for {
 			select {
-			case <-cancelCtx.Done():
+			case <-ctx.Done():
 				return
-			case evt, ok := <-aggregate:
+			case evt, ok := <-a.events:
 				if !ok {
 					return
 				}
 
-				pod, ok := evt.Object.(*v1.Pod)
-				if !ok {
-					continue
-				}
-
-				if !a.podSelector.Select(pod) {
-					continue
-				}
-
 				// TODO(dgageot): Add EphemeralContainerStatuses
+				pod := evt.Pod
 				for _, c := range append(pod.Status.InitContainerStatuses, pod.Status.ContainerStatuses...) {
 					if c.ContainerID == "" {
 						if c.State.Waiting != nil && c.State.Waiting.Message != "" {
@@ -120,7 +103,7 @@ func (a *LogAggregator) Start(ctx context.Context) error {
 					}
 
 					if !a.trackedContainers.add(c.ContainerID) {
-						go a.streamContainerLogs(cancelCtx, pod, c)
+						go a.streamContainerLogs(ctx, pod, c)
 					}
 				}
 			}
@@ -137,9 +120,7 @@ func (a *LogAggregator) Stop() {
 		return
 	}
 
-	if a.cancel != nil {
-		a.cancel()
-	}
+	close(a.events)
 }
 
 func sinceSeconds(d time.Duration) int64 {
@@ -254,6 +235,9 @@ type trackedContainers struct {
 func (t *trackedContainers) add(id string) bool {
 	t.Lock()
 	alreadyTracked := t.ids[id]
+	if t.ids == nil {
+		t.ids = map[string]bool{}
+	}
 	t.ids[id] = true
 	t.Unlock()
 
