@@ -89,6 +89,7 @@ func TestSetDefaults(t *testing.T) {
 	testutil.CheckDeepEqual(t, "fourth", cfg.Build.Artifacts[3].ImageName)
 	testutil.CheckDeepEqual(t, []string{"."}, cfg.Build.Artifacts[3].BuildpackArtifact.Dependencies.Paths)
 	testutil.CheckDeepEqual(t, []string(nil), cfg.Build.Artifacts[3].BuildpackArtifact.Dependencies.Ignore)
+	testutil.CheckDeepEqual(t, "project.toml", cfg.Build.Artifacts[3].BuildpackArtifact.ProjectDescriptor)
 	testutil.CheckDeepEqual(t, &latest.Auto{}, cfg.Build.Artifacts[3].Sync.Auto)
 
 	testutil.CheckDeepEqual(t, "fifth", cfg.Build.Artifacts[4].ImageName)
@@ -158,7 +159,7 @@ func TestSetDefaultsOnCluster(t *testing.T) {
 				Build: latest.BuildConfig{
 					BuildType: latest.BuildType{
 						Cluster: &latest.ClusterDetails{
-							PullSecret: "path/to/pull/secret",
+							PullSecretPath: "path/to/pull/secret",
 						},
 					},
 				},
@@ -177,7 +178,7 @@ func TestSetDefaultsOnCluster(t *testing.T) {
 				Build: latest.BuildConfig{
 					BuildType: latest.BuildType{
 						Cluster: &latest.ClusterDetails{
-							PullSecret:          "path/to/pull/secret",
+							PullSecretPath:      "path/to/pull/secret",
 							PullSecretMountPath: path,
 						},
 					},
